==> commons-component-common-4.4.2-sources.jar: org/exoplatform/settings/chromattic/SimpleContextEntity_Chromattic.java <==
package org.exoplatform.settings.chromattic;
import org.chromattic.apt.Invoker;
import org.chromattic.apt.Instrumented;
public class SimpleContextEntity_Chromattic extends SimpleContextEntity implements Instrumented {
public final org.chromattic.spi.instrument.MethodHandler handler;
public SimpleContextEntity_Chromattic(org.chromattic.spi.instrument.MethodHandler handler) {
this.handler = handler;
}
private static final Invoker method_0 = Invoker.getDeclaredMethod(org.exoplatform.settings.chromattic.SimpleContextEntity.class,"getScopes");
protected final java.util.Map getScopes() {
try {
return (java.util.Map)handler.invoke(this,method_0.getMethod());
} catch(Throwable t) {
if (t instanceof java.lang.RuntimeException) throw (java.lang.RuntimeException)t;
if (t instanceof java.lang.Error) throw (java.lang.Error)t;
throw new java.lang.reflect.UndeclaredThrowableException(t);
}
}
private static final Invoker method_1 = Invoker.getDeclaredMethod(org.exoplatform.settings.chromattic.ContextEntity.class,"remove");
public final void remove() {
try {
handler.invoke(this,method_1.getMethod());
} catch(Throwable t) {
if (t instanceof java.lang.RuntimeException) throw (java.lang.RuntimeException)t;
if (t instanceof java.lang.Error) throw (java.lang.Error)t;
throw new java.lang.reflect.UndeclaredThrowableException(t);
}
}
private static final Invoker method_2 = Invoker.getDeclaredMethod(org.exoplatform.settings.chromattic.SimpleContextEntity.class,"create");
protected final org.exoplatform.settings.chromattic.ScopeEntity create() {
try {
return (org.exoplatform.settings.chromattic.ScopeEntity)handler.invoke(this,method_2.getMethod());
} catch(Throwable t) {
if (t instanceof java.lang.RuntimeException) throw (java.lang.RuntimeException)t;
if (t instanceof java.lang.Error) throw (java.lang.Error)t;
throw new java.lang.reflect.UndeclaredThrowableException(t);
}
}
}

==> commons-component-common-5.0.0-sources.jar: org/exoplatform/settings/chromattic/SimpleContextEntity_Chromattic.java <==
package org.exoplatform.settings.chromattic;
import org.chromattic.apt.Invoker;
import org.chromattic.apt.Instrumented;
public class SimpleContextEntity_Chromattic extends SimpleContextEntity implements Instrumented {
public final org.chromattic.spi.instrument.MethodHandler handler;
public SimpleContextEntity_Chromattic(org.chromattic.spi.instrument.MethodHandler handler) {
this.handler = handler;
}
private static final Invoker method_0 = Invoker.getDeclaredMethod(org.exoplatform.settings.chromattic.SimpleContextEntity.class,"getScopes");
public final java.util.Map getScopes() {
try {
return (java.util.Map)handler.invoke(this,method_0.getMethod());
} catch(Throwable t) {
if (t instanceof java.lang.RuntimeException) throw (java.lang.RuntimeException)t;
if (t instanceof java.lang.Error) throw (java.lang.Error)t;
throw new java.lang.reflect.UndeclaredThrowableException(t);
}
}
private static final Invoker method_1 = Invoker.getDeclaredMethod(org.exoplatform.settings.chromattic.ContextEntity.class,"remove");
public final void remove() {
try {
handler.invoke(this,method_1.getMethod());
} catch(Throwable t) {
if (t instanceof java.lang.RuntimeException) throw (java.lang.RuntimeException)t;
if (t instanceof java.lang.Error) throw (java.lang.Error)t;
throw new java.lang.reflect.UndeclaredThrowableException(t);
}
}
private static final Invoker method_2 = Invoker.getDeclaredMethod(org.exoplatform.settings.chromattic.SimpleContextEntity.class,"create");
protected final org.exoplatform.settings.chromattic.ScopeEntity create() {
try {
return (org.exoplatform.settings.chromattic.ScopeEntity)handler.invoke(this,method_2.getMethod());
} catch(Throwable t) {
if (t instanceof java.lang.RuntimeException) throw (java.lang.RuntimeException)t;
if (t instanceof java.lang.Error) throw (java.lang.Error)t;
throw new java.lang.reflect.UndeclaredThrowableException(t);
}
}
}
